@@ -66,6 +66,7 @@ class LanguagePack:
         self.confirm_new_password = languagepack["ConfirmNewPassword"]
         self.yes = languagepack["Yes"]
         self.assert_false_message = languagepack["AssertFalseMessage"]
+        self.file_name = languagepack["File Name"]
 
         self.messages = Messages(languagepack)
     def get_language_pack(self, language):
@@ -139,7 +140,8 @@ class LanguagePack:
             "NewPassword": "Reserved",
             "ConfirmNewPassword": "Reserved",
             "Yes": "Sim",
-            "AssertFalseMessage": "AssertFalse method used without a checkpoint, check the script."
+            "AssertFalseMessage": "AssertFalse method used without a checkpoint, check the script.",
+            "File Name": "File Name"
             
         }
 
@@ -212,7 +214,9 @@ class LanguagePack:
             "NewPassword": "Nova senha",
             "ConfirmNewPassword": "Confirmar nova senha",
             "Yes": "Sim",
-            "AssertFalseMessage": "Método AssertFalse utilizado sem um ponto de verificação, verifique o script."
+            "AssertFalseMessage": "Método AssertFalse utilizado sem um ponto de verificação, verifique o script.",
+            "File Name": "Nome do Arquivo:"
+        
             
         }
         spanish = {
@@ -284,7 +288,8 @@ class LanguagePack:
             "NewPassword": "Nueva contrasena*",
             "ConfirmNewPassword": "Confirmar nueva contrasena*",
             "Yes":"Reserved",
-            "AssertFalseMessage": "Método AssertFalse utilizado sin un punto de control, verifique el script."
+            "AssertFalseMessage": "Método AssertFalse utilizado sin un punto de control, verifique el script.",
+            "File Name": "Nombre del archivo:"
         }
         russian = {
             "User": "Пользователь",
@@ -358,7 +363,8 @@ class LanguagePack:
             "UserLogin": "Пользователь (логин)",
             "CurrentPassword": "Текущий пароль*",
             "NewPassword": "Нов. пароль*",
-            "ConfirmNewPassword": "Подтв. новый пароль*"
+            "ConfirmNewPassword": "Подтв. новый пароль*",
+            "File Name": "имя файла"
         }
 
         if language.lower() == "en-us":
@@ -371,7 +377,6 @@ class LanguagePack:
             return spanish
         else:
             return brazilian_portuguese
-
 class Messages():
 
     def __init__(self, languagepack):
